@@ -1,7 +1,6 @@
 library(MEMSS)
-options(show.signif.stars = FALSE)
+options(show.signif.stars = FALSE, digits = 3)
 m1 <- lmer(pixel ~ day + I(day^2) + (1|Dog:Side) + (day|Dog),
-           Pixel, verbose = TRUE)
+           Pixel)
 print(m1, corr = FALSE)
-ranef(m1)
-q("no")
+unclass(ranef(m1))
